<?php

/**
 *
 * Copyright © 2016 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace FiloBlu\Newsletter\Controller\Subscriber;

use Magento\Customer\Api\AccountManagementInterface as CustomerAccountManagement;
use Magento\Customer\Model\Session;
use Magento\Customer\Model\Url as CustomerUrl;
use Magento\Framework\App\Action\Context;
use Magento\Store\Model\StoreManagerInterface;
use Magento\Newsletter\Model\SubscriberFactory;

class NewLandingAction extends \Magento\Newsletter\Controller\Subscriber\NewAction {

    protected $jsonResultFactory;
    public $_helper;
    protected $_modelPreConfirm;
    protected $_modelThankYou;

    /**
     * Initialize dependencies.
     *
     * @param Context $context
     * @param SubscriberFactory $subscriberFactory
     * @param Session $customerSession
     * @param StoreManagerInterface $storeManager
     * @param CustomerUrl $customerUrl
     * @param CustomerAccountManagement $customerAccountManagement
     */
    public function __construct(
    Context $context, SubscriberFactory $subscriberFactory, Session $customerSession, StoreManagerInterface $storeManager, CustomerUrl $customerUrl, CustomerAccountManagement $customerAccountManagement, \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory, \FiloBlu\Newsletter\Helper\Data $helper, \FiloBlu\Newsletter\Model\PreConfirm $modelPreConfirm, \FiloBlu\Newsletter\Model\ThankYou $modelThankYou
    ) {
        $this->resultJsonFactory = $resultJsonFactory;
        $this->_helper = $helper;
        $this->_modelPreConfirm = $modelPreConfirm;
        $this->_modelThankYou = $modelThankYou;

        parent::__construct(
                $context, $subscriberFactory, $customerSession, $storeManager, $customerUrl, $customerAccountManagement
        );
    }

    /**
     * Validates that the email address isn't being used by a different account.
     *
     * @param string $email
     * @throws \Magento\Framework\Exception\LocalizedException
     * @return void
     */
    protected function validateEmailAvailable($email) {
        $websiteId = $this->_storeManager->getStore()->getWebsiteId();
        if ($this->_customerSession->getCustomerDataObject()->getEmail() !== $email && !$this->customerAccountManagement->isEmailAvailable($email, $websiteId)
        ) {
            throw new \Magento\Framework\Exception\LocalizedException(
            __('This email address is already assigned to another user.')
            );
        }

        $subscriber = $this->_subscriberFactory->create()->loadByEmail($email);

        if ($subscriber->getSubscriberStatus() == \Magento\Newsletter\Model\Subscriber::STATUS_SUBSCRIBED) {
            throw new \Magento\Framework\Exception\LocalizedException(
            __('This email address is already assigned to another user.')
            );
        }
    }

    /**
     * New subscription action
     *
     * @throws \Magento\Framework\Exception\LocalizedException
     * @return void
     */
    public function execute() {

        if ($this->_helper->getConfig("general/enabled") && $this->getRequest()->isPost() && $this->getRequest()->getPost('email')) {

            $resultJson = $this->resultJsonFactory->create();

            $email = (string) $this->getRequest()->getPost('email');

            try {
                $this->validateEmailFormat($email);
                $this->validateGuestSubscription();
                $this->validateEmailAvailable($email);

                $status = $this->_subscriberFactory->create()->subscribe($email);
              
                if ($status == \Magento\Newsletter\Model\Subscriber::STATUS_NOT_ACTIVE) {
                    if ($this->getRequest()->getPost('preconfirm_id') && $this->getRequest()->getPost('preconfirm_id') != 0) {
                        $this->_helper->setPreConfirmCookie($this->getRequest()->getPost('preconfirm_id'));
                        $resultJson->setData(['success' => true, 'error' => false, 'redirect' => $this->_storeManager->getStore()->getBaseUrl() . $this->_modelPreConfirm->getUrlPreConfirmPageById($this->getRequest()->getPost('preconfirm_id'))->getData()["url_key"]]);
                    } else {
                        $this->messageManager->addSuccess(__('The confirmation request has been sent.'));
                        $resultJson->setData(['success' => true, 'error' => false, 'redirect' => $this->_storeManager->getStore()->getBaseUrl()]);
                    }
                } else {
                    if ($this->getRequest()->getPost('thankyou_id') && $this->getRequest()->getPost('thankyou_id') != 0) {
                        $this->_helper->setThankYouCookie($this->getRequest()->getPost('thankyou_id'));
                        $resultJson->setData(['success' => true, 'error' => false, 'redirect' => $this->_storeManager->getStore()->getBaseUrl() . $this->_modelThankYou->getUrlThankYouPageById($this->getRequest()->getPost('thankyou_id'))->getData()["url_key"]]);
                    } else {
                        $this->messageManager->addSuccess(__('Thank you for your subscription.'));
                        $resultJson->setData(['success' => true, 'error' => false, 'redirect' => $this->_storeManager->getStore()->getBaseUrl()]);
                    }
                }
            } catch (\Magento\Framework\Exception\LocalizedException $e) {
                $resultJson->setData(['success' => false, 'error' => true, 'message' => __('There was a problem with the subscription: %1', $e->getMessage())]);
            } catch (\Exception $e) {
                $resultJson->setData(['success' => false, 'error' => true, 'message' => __($e->getMessage())]);
            }

            return $resultJson;
        } else {
            return null;
        }
    }

}
